@@ -20,9 +20,12 @@
 # If not, see <https://www.gnu.org/licenses/>
 
 
-from .general import Time, Angle, sin, cos, tan, cotan, refraction
-from .earth_motion import Earth
-from .sun_motion import Sun, SunObservation
+from .general import Time, Distance, Angle, AngleArray
+from .general import AngleFromRadians, AngleFromDegrees, AngleFromMinutes, AngleFromSeconds
+from .general import sin, cos, tan, cotan, refraction
+from .general import astronomical_unit
+from .earth import Earth
+from .sun import Sun, SunObservation
 from .tables import generate_table, sunset_table, extend_table
 from .locations import Location
 
